@@ -244,9 +244,6 @@ anova_ind <- function(.data,
 #' print(model)
 #' }
 print.anova_ind <- function(x, export = FALSE, file.name = NULL, digits = 3, ...) {
-  if (!class(x) == "anova_ind") {
-    stop("The object must be of class 'anova_ind'")
-  }
   opar <- options(pillar.sigfig = digits)
   on.exit(options(opar))
   if (export == TRUE) {
