@@ -137,6 +137,17 @@
 #'  **Objects of class `mtsi`:** See the **Value** section of
 #'  [mtsi()] to see valid options for `what` argument.
 #'
+#'  **Objects of class `path_coeff`
+#' * `"coef"` Path coefficients
+#' * `"eigenval"` Eigenvalues and eigenvectors.
+#' * `"vif "` Variance Inflation Factor
+#'
+#'  **Objects of class `path_coeff_seq`
+#' * `"resp_fc"` Coefficients of primary predictors and response
+#' * `"resp_sc"` Coefficients of secondary predictors and response
+#' * `"resp_sc2"` contribution to the total effects through primary traits
+#' * `"fc_sc_coef"` Coefficients of secondary predictors and primary predictors.
+#'
 #'  **Objects of class `Shukla`:**
 #' * `"rMean"` Rank for the mean.
 #' * `"ShuklaVar"` Shukla's stablity variance (default).
@@ -315,17 +326,6 @@
 #' \donttest{
 #' library(metan)
 #'
-#' #################### joint-regression analysis #####################
-#' ge_r <- ge_reg(data_ge2,
-#'                env = ENV,
-#'                gen = GEN,
-#'                rep =  REP,
-#'                resp = c(PH, EH, CD, CL, ED))
-#' get_model_data(ge_r)
-#' # Significance of deviations from the regression
-#' # Use gmd(), a shortcut for get_model_data
-#' gmd(ge_r, "pval_f")
-#'
 #'
 #' #################### WAASB index #####################
 #' # Fitting the WAAS index
@@ -338,9 +338,6 @@
 #' # Getting the weighted average of absolute scores
 #' gmd(AMMI, what = "WAASB")
 #'
-#' # And the rank for the WAASB index.
-#' gmd(AMMI, what = "OrWAASB")
-#'
 #'
 #' #################### BLUP model #####################
 #' # Fitting a mixed-effect model
@@ -349,21 +346,14 @@
 #'                   env = ENV,
 #'                   gen = GEN,
 #'                   rep = REP,
-#'                   resp = c(PH, ED, TKW, NKR))
+#'                   resp = c(PH, ED))
 #'
 #' # Getting p-values for likelihood-ratio test
 #' gmd(blup, what = "lrt")
 #'
 #' # Getting the variance components
 #' gmd(blup, what = "vcomp")
-#'
-#' # Getting the genetic parameters
-#' gmd(blup)
-#'
-#' ### BLUP-based stability indexes ###
-#' blup %>%
-#' blup_indexes() %>%
-#' gmd("HMRPGV_R")
+
 #'
 #'}
 #'
@@ -378,7 +368,8 @@ get_model_data <- function(x,
                       "ge_stats", "Annicchiarico", "Schmildt", "ge_means", "anova_joint",
                       "gafem", "gafem_group", "gamem_group", "anova_ind", "gge", "can_cor",
                       "can_cor_group", "gytb", "ge_acv", "ge_polar", "mgidi", "mtsi",
-                      "env_stratification", "fai_blup", "sh", "mps", "mtmps"))) {
+                      "env_stratification", "fai_blup", "sh", "mps", "mtmps", "path_coeff",
+                      "path_coeff_seq", "group_path_seq", "group_path"))) {
     stop("Invalid class in object ", call_f[["x"]], ". See ?get_model_data for more information.", call. = FALSE)
   }
   if (!is.null(what) && what != "PCA" && substr(what, 1, 2) == "PC") {
@@ -407,7 +398,7 @@ get_model_data <- function(x,
               "FA_R","FA_SSI","MASI","MASI_R","MASI_SSI","MASV","MASV_R","MASV_SSI","SIPC","SIPC_R","SIPC_SSI",
               "ZA","ZA_R","ZA_SSI","WAAS","WAAS_R","WAAS_SSI")
   check8 <- c("Ecoval", "Ecov_perc", "rank")
-  check9 <- c("GEN", "b0", "b1", "t(b1=1)", "pval_t", "s2di", "F(s2di=0)", "pval_f", "RMSE", "R2")
+  check9 <- c("GEN", "b0", "b1", "t(b1=1)", "pval_t", "s2di", "F(s2di=0)", "pval_f", "RMSE", "R2", "coefs", "anova")
   check10 <- c("TOP")
   check11 <- c("ShuklaVar", "rMean", "rShukaVar", "ssiShukaVar")
   check12 <- c("Pi_a", "R_a", "Pi_f", "R_f", "Pi_u", "R_u")
@@ -443,6 +434,61 @@ get_model_data <- function(x,
   check32 <- c("observed", "performance", "performance_res", "stability",
                "stability_res", "mps_ind", "h2", "perf_method", "wmper",
                "sense_mper", "stab_method", "wstab", "sense_stab")
+  check33 <- c("coef", "eigenval", "vif")
+  check34 <- c("resp_fc", "resp_sc", "resp_sc2", "fc_sc_coef")
+  if(has_class(x, c("path_coeff", "group_path"))){
+    if (is.null(what)){
+      what <- "coef"
+    }
+    if (!what %in% check33) {
+      stop("Invalid value in 'what' for object of class 'path_coeff'. Allowed are ", paste(check33, collapse = ", "), call. = FALSE)
+    }
+    what <-
+      switch(what,
+             "coef" = "Coefficients",
+             "eigenval" = "Eigen",
+             "vif" = "vif")
+    if(has_class(x, "group_path")){
+      bind <-
+        x %>%
+        mutate(data = map(data, ~.x %>% .[[what]])) %>%
+        unnest(data)
+    } else{
+      bind <- x[[what]]
+    }
+  }
+
+  if (has_class(x, c("path_coeff_seq", "group_path_seq"))){
+    if (is.null(what)){
+      what <- "resp_sc2"
+    }
+    if (!what %in% check34) {
+      stop("Invalid value in 'what' for object of class 'path_coeff_seq'. Allowed are ", paste(check34, collapse = ", "), call. = FALSE)
+    }
+    if(has_class(x, "group_path_seq")){
+      if(what %in% c("resp_fc", "resp_sc")){
+        bind <-
+          x %>%
+          mutate(data = map(data, ~.x %>% .[[what]][["Coefficients"]])) %>%
+          unnest(data)
+      } else{
+        bind <-
+          x %>%
+          mutate(data = map(data, ~.x %>% .[[what]])) %>%
+          unnest(data)
+      }
+    } else{
+      if(what %in% c("resp_fc", "resp_sc")){
+        bind <- x[[what]][["Coefficients"]]
+      } else{
+        bind <- x[[what]]
+      }
+    }
+  }
+
+
+
+
   if (!is.null(what) && what %in% check3 && !has_class(x, c("waasb", "waas", "waasb_group", "gamem", "gamem_group", "gafem", "anova_joint"))) {
     stop("Invalid argument 'what'. It can only be used with an oject of class 'waasb' or 'gamem', 'gafem, or 'anova_joint'. Please, check and fix.")
   }
@@ -1010,9 +1056,9 @@ get_model_data <- function(x,
     }
     if(what == "FMAX"){
       bind <-
-      sapply(x, function(x) {
-        x[["MSRratio"]]
-      }) %>%
+        sapply(x, function(x) {
+          x[["MSRratio"]]
+        }) %>%
         as.data.frame() %>%
         rownames_to_column("TRAIT") %>%
         setNames(c("TRAIT", "F_RATIO"))
@@ -1020,16 +1066,16 @@ get_model_data <- function(x,
     if(what == "ALL"){
       bind <-
         lapply(x, function(x){
-        x[[1]]
-      }) %>%
+          x[[1]]
+        }) %>%
         rbind_fill_id(.id = "trait")
     } else{
-    bind <- sapply(x, function(x) {
-      x[["individual"]][[what]]
-    }) %>%
-      as_tibble() %>%
-      mutate(ENV = x[[1]][["individual"]][["ENV"]]) %>%
-      column_to_first(ENV)
+      bind <- sapply(x, function(x) {
+        x[["individual"]][[what]]
+      }) %>%
+        as_tibble() %>%
+        mutate(ENV = x[[1]][["individual"]][["ENV"]]) %>%
+        column_to_first(ENV)
     }
   }
   if (has_class(x, c("anova_joint", "gafem", "gafem_group"))) {
@@ -1040,45 +1086,45 @@ get_model_data <- function(x,
         unnest(bind) %>%
         remove_cols(data)
     } else{
-    if (is.null(what)){
-      what <- "fitted"
-    }
-    if (!what %in% c(check20)) {
-      stop("Invalid value in 'what' for object of class, ", class(x), ". Allowed are ", paste(check20, collapse = ", "), call. = FALSE)
-    }
-    if(what %in% c("Sum Sq", "Mean Sq", "F value", "Pr(>F)")){
-      bind <- sapply(x, function(x) {
-        x[["anova"]][[what]]
-      }) %>%
-        as_tibble()
-      bind <- cbind(x[[1]][["anova"]] %>% select_non_numeric_cols(), bind) %>%
-        remove_rows_na(verbose = FALSE)
-    }
-    if(what  == "h2"){
-      bind <- sapply(x, function(x){
-        MSG <- as.numeric(x[["anova"]][which(x[["anova"]][["Source"]] == "GEN"), 4])
-        MSE <- as.numeric(x[["anova"]][which(x[["anova"]][["Source"]] == "Residuals"), 4])
-        (MSG - MSE) / MSG
-      }) %>%
-        as.data.frame() %>%
-        rownames_to_column("VAR") %>%
-        set_names("VAR", "h2")
-    }
-    if(what %in% c("Y", "fitted", "resid", "stdres", "se.fit")){
-      bind <- sapply(x, function(x){
-        x[["augment"]][[what]]
-      }) %>%  as_tibble()
-      bind <- cbind(x[[1]][["augment"]] %>% select_non_numeric_cols(), bind) %>%
-        as_tibble()
-    }
-    if(what == "details"){
-      bind <- sapply(x, function(x){
-        x[["details"]][[2]]
-      }) %>%
-        as_tibble() %>%
-        mutate(Parameters = x[[1]][["details"]][["Parameters"]]) %>%
-        column_to_first(Parameters)
-    }
+      if (is.null(what)){
+        what <- "fitted"
+      }
+      if (!what %in% c(check20)) {
+        stop("Invalid value in 'what' for object of class, ", class(x), ". Allowed are ", paste(check20, collapse = ", "), call. = FALSE)
+      }
+      if(what %in% c("Sum Sq", "Mean Sq", "F value", "Pr(>F)")){
+        bind <- sapply(x, function(x) {
+          x[["anova"]][[what]]
+        }) %>%
+          as_tibble()
+        bind <- cbind(x[[1]][["anova"]] %>% select_non_numeric_cols(), bind) %>%
+          remove_rows_na(verbose = FALSE)
+      }
+      if(what  == "h2"){
+        bind <- sapply(x, function(x){
+          MSG <- as.numeric(x[["anova"]][which(x[["anova"]][["Source"]] == "GEN"), 4])
+          MSE <- as.numeric(x[["anova"]][which(x[["anova"]][["Source"]] == "Residuals"), 4])
+          (MSG - MSE) / MSG
+        }) %>%
+          as.data.frame() %>%
+          rownames_to_column("VAR") %>%
+          set_names("VAR", "h2")
+      }
+      if(what %in% c("Y", "fitted", "resid", "stdres", "se.fit")){
+        bind <- sapply(x, function(x){
+          x[["augment"]][[what]]
+        }) %>%  as_tibble()
+        bind <- cbind(x[[1]][["augment"]] %>% select_non_numeric_cols(), bind) %>%
+          as_tibble()
+      }
+      if(what == "details"){
+        bind <- sapply(x, function(x){
+          x[["details"]][[2]]
+        }) %>%
+          as_tibble() %>%
+          mutate(Parameters = x[[1]][["details"]][["Parameters"]]) %>%
+          column_to_first(Parameters)
+      }
     }
   }
 
@@ -1278,12 +1324,29 @@ get_model_data <- function(x,
     if (!what %in% c(check9)) {
       stop("Invalid value in 'what' for object of class 'ge_reg'. Allowed are ", paste(check9, collapse = ", "), call. = FALSE)
     }
-    bind <- sapply(x, function(x) {
-      x[["regression"]][[what]]
-    }) %>%
-      as_tibble() %>%
-      mutate(GEN = x[[1]][["regression"]][["GEN"]]) %>%
-      column_to_first(GEN)
+    if(what %in% c("coefs", "anova")){
+      if(what == "coefs"){
+        bind <-
+          lapply(x, function(x){
+            x$regression
+          }) %>%
+          rbind_fill_id(.id = "TRAIT")
+      } else{
+        bind <-
+          lapply(x, function(x){
+            x$anova
+          }) %>%
+          rbind_fill_id(.id = "TRAIT")
+      }
+    } else{
+      bind <- sapply(x, function(x) {
+        x[["regression"]][[what]]
+      }) %>%
+        as_tibble() %>%
+        mutate(GEN = x[[1]][["regression"]][["GEN"]]) %>%
+        column_to_first(GEN)
+    }
+
   }
 
   if (has_class(x,  "ecovalence")) {
