@@ -290,9 +290,6 @@ waas_means <- function(.data,
 #' print(model)
 #' }
 print.waas_means <- function(x, export = FALSE, file.name = NULL, digits = 4, ...) {
-  if (!class(x) == "waas_means") {
-    stop("The object must be of class 'waas_means'")
-  }
   if (export == TRUE) {
     file.name <- ifelse(is.null(file.name) == TRUE, "waas_means print", file.name)
     sink(paste0(file.name, ".txt"))
